import PlaygroundSupport
import SpriteKit

class GameScene: SKScene {
    override func didMove(to view: SKView) {
        // add game over label
        let gameOverLabel = SKLabelNode(text: "GAME OVER")
        gameOverLabel.fontName = "AvenirNext-Heavy"
        gameOverLabel.fontColor = backgroundColor
        gameOverLabel.position = CGPoint(x: size.width/2, y: size.height/2)
        addChild(gameOverLabel)
        
        // add try again label
        let tryAgainLabel = SKLabelNode(text: "TRY AGAIN")
        tryAgainLabel.fontName = "AvenirNext"
        tryAgainLabel.fontColor = backgroundColor
        tryAgainLabel.position = CGPoint(x: size.width/2, y: 16)
        addChild(tryAgainLabel)
        
        // add spotlight
        let shapeNode = SKShapeNode(circleOfRadius: 30)
        shapeNode.fillColor = .white
        shapeNode.strokeColor = .white
        shapeNode.glowWidth = 90
        shapeNode.position = CGPoint(x: size.width/2, y: size.height/2)
        shapeNode.zPosition = -1
        addChild(shapeNode)
        
        // animate
        let sequence = [
            SKAction.moveBy(x: 20, y: 10, duration: 0.75),
            SKAction.moveBy(x: -40, y: -20, duration: 1.5),
            SKAction.moveBy(x: 40, y: 0, duration: 1.5),
            SKAction.moveBy(x: -20, y: 10, duration: 0.75),
        ]
        sequence.forEach { $0.timingMode = .easeInEaseOut }
        let animation = SKAction.sequence(sequence)

        shapeNode.run(animation) {
            shapeNode.physicsBody = SKPhysicsBody(circleOfRadius: 1)
        }
        physicsBody = SKPhysicsBody(edgeLoopFrom: frame)
    }
    
    override func touchesEnded(_ touches: Set<UITouch>, with event: UIEvent?) {
        let scene = GameScene(size: size)
        let reveal = SKTransition.fade(with: backgroundColor, duration: 0.5)
        view?.presentScene(scene, transition: reveal)
    }
}

let sceneView = SKView(frame: CGRect(x:0 , y:0, width: 640, height: 480))
let scene = GameScene(size: sceneView.bounds.size)

sceneView.presentScene(scene)

PlaygroundSupport.PlaygroundPage.current.liveView = sceneView
